@@ -1,9 +1,9 @@
 !
-!  This file is part of MUMPS 5.4.1, released
-!  on Tue Aug  3 09:49:43 UTC 2021
+!  This file is part of MUMPS 5.5.1, released
+!  on Tue Jul 12 13:17:24 UTC 2022
 !
 !
-!  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Copyright 1991-2022 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
 !  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
