@@ -1,9 +1,9 @@
 C
-C  This file is part of MUMPS 5.4.1, released
-C  on Tue Aug  3 09:49:43 UTC 2021
+C  This file is part of MUMPS 5.5.1, released
+C  on Tue Jul 12 13:17:24 UTC 2022
 C
 C
-C  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+C  Copyright 1991-2022 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
 C  Mumps Technologies, University of Bordeaux.
 C
 C  This version of MUMPS is provided to you free of charge. It is
@@ -328,6 +328,15 @@ C***********************************************************************
       IERR = 0
       RETURN
       END SUBROUTINE MPI_GROUP_SIZE
+C***********************************************************************
+      SUBROUTINE MPI_INIT_THREAD(MPI_THREAD_REQ, THREAD_SUPPORT, IERR)
+      IMPLICIT NONE
+      INCLUDE 'mpif.h'
+      INTEGER IERR, MPI_THREAD_REQ, THREAD_SUPPORT
+      IERR = 0
+      THREAD_SUPPORT=MPI_THREAD_REQ
+      RETURN
+      END SUBROUTINE MPI_INIT_THREAD
 C***********************************************************************
       SUBROUTINE MPI_INIT(IERR)
       IMPLICIT NONE
