@@ -1,9 +1,9 @@
 !
-!  This file is part of MUMPS 5.4.1, released
-!  on Tue Aug  3 09:49:43 UTC 2021
+!  This file is part of MUMPS 5.5.1, released
+!  on Tue Jul 12 13:17:24 UTC 2022
 !
 !
-!  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Copyright 1991-2022 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
 !  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
@@ -50,6 +50,9 @@
       INTEGER MPI_REAL8
       INTEGER MPI_COMM_SELF
       INTEGER MPI_BSEND_OVERHEAD
+      INTEGER MPI_THREAD_SINGLE
+      INTEGER MPI_THREAD_FUNNELED
+      INTEGER MPI_THREAD_MULTIPLE
       PARAMETER (MPI_2DOUBLE_PRECISION=1)
       PARAMETER (MPI_2INTEGER=2)
       PARAMETER (MPI_2REAL=3)
@@ -85,6 +88,9 @@
       PARAMETER (MPI_INTEGER8=33)
       PARAMETER (MPI_REAL8=34)
       PARAMETER (MPI_COMM_SELF=35)
+      PARAMETER (MPI_THREAD_SINGLE=36)
+      PARAMETER (MPI_THREAD_FUNNELED=37)
+      PARAMETER (MPI_THREAD_MULTIPLE=38)
 
       INTEGER MPI_IN_PLACE
       COMMON/mpif_libseq/MPI_IN_PLACE
