@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.4.1, released
- *  on Tue Aug  3 09:49:43 UTC 2021
+ *  This file is part of MUMPS 5.5.1, released
+ *  on Tue Jul 12 13:17:24 UTC 2022
  *
  *
- *  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2022 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -13,6 +13,7 @@
  *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
  *
  */
+#include <stdlib.h>
 #include "mumps_common.h"
 /* Special case of mapping and pivnul_list -- allocated from MUMPS */
 static MUMPS_INT * MUMPS_MAPPING;
@@ -105,3 +106,15 @@ MUMPS_ICOPY_64TO32_64C_IP_C(MUMPS_INT8 *inouttab, MUMPS_INT8 *sizetab)
        ((MUMPS_INT *)inouttab)[i8]=(MUMPS_INT)inouttab[i8];
      }
 }
+void MUMPS_CALL
+MUMPS_MALLOC_C(MUMPS_INT8 *address, MUMPS_INT8 *size)
+{
+  void * ptr;
+  ptr=malloc(*size);
+  *address=(MUMPS_INT8)(ptr);
+}
+void MUMPS_CALL
+MUMPS_FREE_C(void *address)
+{
+  free(address);
+}
